==> blesta-5.10.2.zip: blesta/language/da_dk/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.!error.unauthorized_access'] = 'Du er ikke autoriseret til at tilgå denne ressource';
$lang['AppController.!error.invalid_csrf'] = 'Formular-tokenet er ugyldigt.';
$lang['AppController.!success.license_updated'] = 'Din licens er blevet forlænget. Log venligst ind.';
$lang['AppController.!success.license_key_updated'] = 'Din licensnøgle blev opdateret. Log venligst ind.';
$lang['AppController.select.please'] = '-- Vælg venligst --';
$lang['AppController.modal.text_close'] = 'Luk';
$lang['AppController.modal.text_confirm'] = 'Bekræft venligst';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.banners.client_manager'] = 'Du administrerer i øjeblikket en konto, som har inviteret dig til at administrere den.';
$lang['AppController.banners.text_switch_back'] = 'Skift tilbage til min konto';
$lang['AppController.message.close'] = '×';
$lang['AppController.structure.text_myinfo'] = 'Mine oplysninger';
$lang['AppController.structure.text_settings'] = 'Indstillinger';
$lang['AppController.structure.text_logout'] = 'Log ud';
$lang['AppController.structure.text_maintenance'] = 'Vedligeholdelsestilstand er i øjeblikket aktiveret, og klienter kan ikke logge ind. Klik her for at ændre.';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.client_structure.staff_as_client_note'] = 'Tilbage til personaleportalen';
$lang['AppController.client_structure.default_title'] = 'Min konto';
$lang['AppController.client_structure.text_return_to_portal'] = 'Tilbage til portalen';
$lang['AppController.client_structure.text_logout'] = 'Log ud';
$lang['AppController.client_structure.text_login'] = 'Log ind';
$lang['AppController.client_structure.text_update_account'] = 'Administrer konto';
$lang['AppController.client_structure.text_emails'] = 'E-mail-historie';
$lang['AppController.client_structure.text_accounts'] = 'Betalingskonti';
$lang['AppController.client_structure.text_contacts'] = 'Kontaktpersoner';
$lang['AppController.client_structure.text_managers'] = 'Ledere';
$lang['AppController.dates.day_sun'] = 'Søndag';
$lang['AppController.dates.day_mon'] = 'Mandag';
$lang['AppController.dates.day_tue'] = 'Tirsdag';
$lang['AppController.dates.day_wed'] = 'Onsdag';
$lang['AppController.dates.day_thu'] = 'Torsdag';
$lang['AppController.dates.day_fri'] = 'Fredag';
$lang['AppController.dates.day_sat'] = 'Lørdag';
$lang['AppController.dates.dayabbr_sun'] = 'Sol';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_tue'] = 'Tirsdag';
$lang['AppController.dates.dayabbr_wed'] = 'Onsdag';
$lang['AppController.dates.dayabbr_thur'] = 'Torsdag';
$lang['AppController.dates.dayabbr_fri'] = 'Fri';
$lang['AppController.dates.dayabbr_sat'] = 'Lør';
$lang['AppController.dates.month_jan'] = 'Januar';
$lang['AppController.dates.month_feb'] = 'Februar';
$lang['AppController.dates.month_mar'] = 'Marts';
$lang['AppController.dates.month_apr'] = 'April';
$lang['AppController.dates.month_may'] = 'maj';
$lang['AppController.dates.month_jun'] = 'Juni';
$lang['AppController.dates.month_jul'] = 'Juli';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_sep'] = 'September';
$lang['AppController.dates.month_oct'] = 'Oktober';
$lang['AppController.dates.month_nov'] = 'November';
$lang['AppController.dates.month_dec'] = 'December';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.monthabbr_feb'] = 'Februar';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_apr'] = 'Apr';
$lang['AppController.dates.monthabbr_may'] = 'maj';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_oct'] = 'Oktober';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_dec'] = 'Dec';
$lang['AppController.graphs.control_label.stacked'] = 'Stablet';
$lang['AppController.graphs.control_label.stream'] = 'Strøm';
$lang['AppController.graphs.control_label.expanded'] = 'Udvidet';
$lang['AppController.graphs.control_label.grouped'] = 'Grupperet';
$lang['AppController.graphs.label.total'] = 'I alt';
$lang['AppController.sreader.dropdown'] = 'Slå rullemenuen til';
$lang['AppController.sreader.navigation'] = 'Toggle navigation';
$lang['AppController.dropzone.text'] = 'Læg filer her for at uploade eller klik for at vælge filer';

==> blesta-5.11.4.zip: blesta/language/da_dk/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.!error.unauthorized_access'] = 'Du er ikke autoriseret til at tilgå denne ressource';
$lang['AppController.!error.invalid_csrf'] = 'Formular-tokenet er ugyldigt.';
$lang['AppController.!success.license_updated'] = 'Din licens er blevet forlænget. Log venligst ind.';
$lang['AppController.!success.license_key_updated'] = 'Din licensnøgle blev opdateret. Log venligst ind.';
$lang['AppController.select.please'] = '-- Vælg venligst --';
$lang['AppController.modal.text_close'] = 'Luk';
$lang['AppController.modal.text_confirm'] = 'Bekræft venligst';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.banners.client_manager'] = 'Du administrerer i øjeblikket en konto, som har inviteret dig til at administrere den.';
$lang['AppController.banners.text_switch_back'] = 'Skift tilbage til min konto';
$lang['AppController.message.close'] = '×';
$lang['AppController.structure.text_myinfo'] = 'Mine oplysninger';
$lang['AppController.structure.text_settings'] = 'Indstillinger';
$lang['AppController.structure.text_logout'] = 'Log ud';
$lang['AppController.structure.text_maintenance'] = 'Vedligeholdelsestilstand er i øjeblikket aktiveret, og klienter kan ikke logge ind. Klik her for at ændre.';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.client_structure.staff_as_client_note'] = 'Tilbage til personaleportalen';
$lang['AppController.client_structure.default_title'] = 'Min konto';
$lang['AppController.client_structure.text_return_to_portal'] = 'Tilbage til portalen';
$lang['AppController.client_structure.text_logout'] = 'Log ud';
$lang['AppController.client_structure.text_login'] = 'Log ind';
$lang['AppController.client_structure.text_update_account'] = 'Administrer konto';
$lang['AppController.client_structure.text_emails'] = 'E-mail-historie';
$lang['AppController.client_structure.text_accounts'] = 'Betalingskonti';
$lang['AppController.client_structure.text_contacts'] = 'Kontaktpersoner';
$lang['AppController.client_structure.text_managers'] = 'Ledere';
$lang['AppController.dates.day_sun'] = 'Søndag';
$lang['AppController.dates.day_mon'] = 'Mandag';
$lang['AppController.dates.day_tue'] = 'Tirsdag';
$lang['AppController.dates.day_wed'] = 'Onsdag';
$lang['AppController.dates.day_thu'] = 'Torsdag';
$lang['AppController.dates.day_fri'] = 'Fredag';
$lang['AppController.dates.day_sat'] = 'Lørdag';
$lang['AppController.dates.dayabbr_sun'] = 'Sol';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_tue'] = 'Tirsdag';
$lang['AppController.dates.dayabbr_wed'] = 'Onsdag';
$lang['AppController.dates.dayabbr_thur'] = 'Torsdag';
$lang['AppController.dates.dayabbr_fri'] = 'Fri';
$lang['AppController.dates.dayabbr_sat'] = 'Lør';
$lang['AppController.dates.month_jan'] = 'Januar';
$lang['AppController.dates.month_feb'] = 'Februar';
$lang['AppController.dates.month_mar'] = 'Marts';
$lang['AppController.dates.month_apr'] = 'April';
$lang['AppController.dates.month_may'] = 'maj';
$lang['AppController.dates.month_jun'] = 'Juni';
$lang['AppController.dates.month_jul'] = 'Juli';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_sep'] = 'September';
$lang['AppController.dates.month_oct'] = 'Oktober';
$lang['AppController.dates.month_nov'] = 'November';
$lang['AppController.dates.month_dec'] = 'December';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.monthabbr_feb'] = 'Februar';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_apr'] = 'Apr';
$lang['AppController.dates.monthabbr_may'] = 'maj';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_oct'] = 'Oktober';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_dec'] = 'Dec';
$lang['AppController.graphs.control_label.stacked'] = 'Stablet';
$lang['AppController.graphs.control_label.stream'] = 'Strøm';
$lang['AppController.graphs.control_label.expanded'] = 'Udvidet';
$lang['AppController.graphs.control_label.grouped'] = 'Grupperet';
$lang['AppController.graphs.label.total'] = 'I alt';
$lang['AppController.sreader.dropdown'] = 'Slå rullemenuen til';
$lang['AppController.sreader.navigation'] = 'Toggle navigation';
$lang['AppController.dropzone.text'] = 'Læg filer her for at uploade eller klik for at vælge filer';
$lang['AppController.!error.client_unauthorized_access'] = 'Du har ikke tilladelse til at få adgang til denne ressource, kontakt venligst den primære kontoindehaver for at anmode om adgang.';
